==> qtjambi-quickcontrols-debuginfo-macos-6.6.0.jar: sources/QtJambiQuickControls2/QQuickAttachedPropertyPropagator_shell.h <==
#ifndef QQUICKATTACHEDPROPERTYPROPAGATOR_SHELL_H
#define QQUICKATTACHEDPROPERTYPROPAGATOR_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtQuickControls2/qquickattachedpropertypropagator.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtJambi/RegistryAPI>


class QQuickAttachedPropertyPropagator_shell : public QQuickAttachedPropertyPropagator, public QtJambiShellInterface
{
public:
    QQuickAttachedPropertyPropagator_shell(QObject* parent0 = nullptr);
    ~QQuickAttachedPropertyPropagator_shell() override;

    void attachedParentChange(QQuickAttachedPropertyPropagator* newParent0, QQuickAttachedPropertyPropagator* oldParent1) override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QQuickAttachedPropertyPropagator_access : public QQuickAttachedPropertyPropagator
{
    void __qt_initialize(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_attachedParentChange_QQuickAttachedPropertyPropagator_ptr_QQuickAttachedPropertyPropagator_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID newParent0, QtJambiNativeID oldParent1);
};

#endif // QQUICKATTACHEDPROPERTYPROPAGATOR_SHELL_H

==> qtjambi-quickcontrols-debuginfo-macos-6.7.2.jar: sources/QtJambiQuickControls2/QQuickAttachedPropertyPropagator_shell.h <==
#ifndef QQUICKATTACHEDPROPERTYPROPAGATOR_SHELL_H
#define QQUICKATTACHEDPROPERTYPROPAGATOR_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtQuickControls2/qquickattachedpropertypropagator.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtJambi/RegistryAPI>


class QQuickAttachedPropertyPropagator_shell : public QQuickAttachedPropertyPropagator, public QtJambiShellInterface
{
public:
    QQuickAttachedPropertyPropagator_shell(QObject* parent0 = nullptr);
    ~QQuickAttachedPropertyPropagator_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QQuickAttachedPropertyPropagator_mshell;
    friend class QQuickAttachedPropertyPropagator_oshell;
};


class QQuickAttachedPropertyPropagator_mshell : public QQuickAttachedPropertyPropagator_shell
{
public:
    using QQuickAttachedPropertyPropagator_shell::QQuickAttachedPropertyPropagator_shell;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QQuickAttachedPropertyPropagator_oshell : public QQuickAttachedPropertyPropagator_mshell
{
public:
    using QQuickAttachedPropertyPropagator_mshell::QQuickAttachedPropertyPropagator_mshell;
    void attachedParentChange(QQuickAttachedPropertyPropagator* newParent0, QQuickAttachedPropertyPropagator* oldParent1) override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QQuickAttachedPropertyPropagator_access : public QQuickAttachedPropertyPropagator
{
    void __qt_initialize(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_attachedParentChange_QQuickAttachedPropertyPropagator_ptr_QQuickAttachedPropertyPropagator_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID newParent0, QtJambiNativeID oldParent1);
};

#endif // QQUICKATTACHEDPROPERTYPROPAGATOR_SHELL_H
